<!-- markdownlint-disable -->

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `extras.log_monitor.log_table_view`




**Global Variables**
---------------
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**
- **log_levels**
- **default_columns**
- **db_conn_name**
- **session_start_time**


---

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L12"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `LogDbModel`




<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L13"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogDbModel.__init__`

```python
__init__(parent=None)
```








---

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L17"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogDbModel.data`

```python
data(index, role=PySide6.QtCore.Qt.ItemDataRole.DisplayRole)
```






---

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L30"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `LogTableView`




<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L31"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogTableView.__init__`

```python
__init__()
```








---

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L55"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogTableView.attempt_refresh`

```python
attempt_refresh()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L83"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogTableView.eventFilter`

```python
eventFilter(object, event)
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L94"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogTableView.header_menu`

```python
header_menu()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L89"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogTableView.mouse_released`

```python
mouse_released()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L68"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogTableView.refresh`

```python
refresh()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L61"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogTableView.schedule_refresh`

```python
schedule_refresh()
```





---

<a href="..\..\qtstrap\extras\log_monitor\log_table_view.py#L64"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `LogTableView.set_filter`

```python
set_filter(filt)
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
